###      CrossBlog.pl
###      A Movable Type plugin to post an entry on a different blog.
###      For example, if you have two blogs and you want to post
###      an entry on one blog announcing that you've posted something
###      on your other blog.
###      Copyright 2003 by Eric James Stone
###      http://www.ericjamesstone.com/
###      version 1.00
###      last modified 8 November 2003

package MT::Plugin::CrossBlog;

use MT::Template::Context;
use Net::Blogger;

###            VERY IMPORTANT NOTE: 
###            While it is not required from a code standpoint, from a usability
###            standpoint you will need the HighWater plugin. Why? Because you
###            need some way to tell whether an entry is brand new or just being
###            rebuilt. Otherwise, every rebuild could cause CrossBlog to post
###            a new entry to the other blog.
###
###            You should install the HighWater plugin and make sure that there
###            is a HighWater.txt file containing the entry number of your
###            latest blog entry. Otherwise, it may consider every entry as being
###            new, and CrossBlog might try to post every entry to the other blog.
###            (Of course, that can actually work to your benefit if you want to
###            transfer all your entries to another blog.)

MT::Template::Context->add_container_tag(CrossBlog => \&CrossBlog);

###      Usage example:
###
###      <MTIfNewHighWater>
###       <MTCrossBlog
###         blogid='4'
### 				username='user'
###					password='pass'
###					proxy='http://someplace.com/cgi-bin/mt/mt-xmlrpc.cgi'
###         title='A new entry on my other blog'
###				>
###        <B><a href="<$MTEntryPermalink$>"><$MTEntryTitle$></A></B>: <MTEntryExcerpt> 
###       </MTCrossBlog>
###      </MTIfNewHighWater>


sub xCrossBlog {
	return "Crossblog worked";
}

sub CrossBlog {
  my ($ctx, $args) = @_;																			### Get context and arguments
	my $entry_title = $ctx->stash('entry')->title;							### Get the title of the current entry.
	if ($entry_title=~/<!-- Added by Crossblog -->/i) {					    ### Check to see if this entry was added by CrossBlog.
		return "<!-- CrossBlog: Preventing feedback loop -->";	### If so, do not post it to somewhere else.
	} else {
		my $id          = $args->{blogid}   || "1";								### Get blog ID from argument, otherwise use a default.
		my $username    = $args->{username} || "username";        ### Get username from argument, otherwise use a default.
		my $password    = $args->{password} || "password";        ### Get password from argument, otherwise use a default.
		my $proxy       = $args->{proxy}    || "http://yoursite.com/cgi-bin/MT/mt-xmlrpc.cgi"; ### Get URL to mt-xmlrpc.cgi from argument, otherwise use a default.
		my $blog_name   = $args->{blogname} || $ctx->stash('blog')->name; ### Get blog name from argument, otherwise use a default.
		my $title       = $args->{title}    || "New entry at $blog_name"; ### Get title from argument, otherwise use a default.
		my $builder     = $ctx->stash('builder');									### Get information used to build 
		my $tokens      = $ctx->stash('tokens');									### the content inside the body,
		defined(my $out = $builder->build($ctx, $tokens))					### and then build the body
                or return $ctx->error($builder->errstr);			### or throw an error.
		$title = $title."<!-- Added by Crossblog -->";						### Put a comment in the title to prevent CrossBlog from looping.
		my $mt = Net::Blogger->new(engine=>"movabletype");				### Create a Blogger object.
		$mt->Proxy($proxy); 																			### Set the proxy to the target.
		$mt->Username($username);																	### Set the user for the target.
		$mt->Password($password);																	### Set the password for the target.
		$mt->BlogId($id);																					### Set the target blog ID.
		my $post_id = $mt->metaWeblog()->newPost(															### Create a new entry on the target blog.
																								title => $title,					### Set the title of the entry.
																								description => $out,			### Set the body of the entry.
																								publish => 1							### Publish the entry.
																							) || die $mt->LastError();	### Get error on failure.
		return "<!-- CrossBlog: Successfully posted #$post_id -->"; ### Insert a comment with result.

	}
}
1;